From ae070732d9a08fd4d1741530a9b51a19ab027d26 Mon Sep 17 00:00:00 2001
From: Till Brehm <tbrehm@ispconfig.org>
Date: Mon, 10 Feb 2014 04:57:09 -0500
Subject: [PATCH] Fixed issue with shell user creation due to missing parent user and group values in shell_user database records.

---
 interface/web/sites/shell_user_list.php |   14 ++++++--------
 1 files changed, 6 insertions(+), 8 deletions(-)

diff --git a/interface/web/sites/shell_user_list.php b/interface/web/sites/shell_user_list.php
index 3909b84..8a47ebc 100644
--- a/interface/web/sites/shell_user_list.php
+++ b/interface/web/sites/shell_user_list.php
@@ -28,8 +28,8 @@
 EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
-require_once('../../lib/config.inc.php');
-require_once('../../lib/app.inc.php');
+require_once '../../lib/config.inc.php';
+require_once '../../lib/app.inc.php';
 
 /******************************************
 * Begin Form configuration
@@ -41,18 +41,16 @@
 * End Form configuration
 ******************************************/
 
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'sites')) {
-	header("Location: ../index.php");
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('sites');
 
 $app->uses('listform_actions');
 
 // Limit the results to alias domains
 //$app->listform_actions->SQLExtWhere = "type = 'subdomain'";
 
+$app->listform_actions->SQLOrderBy = 'ORDER BY shell_user.username';
 $app->listform_actions->onLoad();
 
 
-?>
\ No newline at end of file
+?>

--
Gitblit v1.9.1